==> nextcloud-app-news-1:26.1.0-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/news/l10n/lv.js <==
OC.L10N.register(
    "news",
    {
    "Unread articles" : "Nelasītie raksti",
    "Shared with me" : "Koplietots ar mani",
    "Download" : "Lejupielādēt",
    "Close" : "Aizvērt",
    "Web address" : "Tīmekļa adrese",
    "No folder" : "Nav mapes",
    "Folder name" : "Mapes nosaukums",
    "Username" : "Lietotājvārds",
    "Password" : "Parole",
    "Feed exists already!" : "Plūsma jau pastāv.",
    "New folder" : "Jauna mape",
    "Folder exists already!" : "Mape jau pastāv.",
    "Credentials" : "Akreditācijas dati",
    "Subscribe" : "Abonēt",
    "Maximum redirects" : "Lielākais pieļaujamais pārvirzījumu skaits",
    "Use system cron for updates" : "Izmantot sistēmas cron atjauninājumiem",
    "Show all articles" : "Rādīt visus rakstus",
    "Move" : "Pārvietot",
    "Share" : "Koplietot",
    "Rename Folder" : "Pārdēvēt mapi",
    "All articles" : "Visi raksti",
    "Starred" : "Svarīgs",
    "Explore" : "Izpētīt",
    "Settings" : "Iestatījumi",
    "Documentation" : "Dokumentācija",
    "Keyboard shortcuts" : "Tastatūras saīsnes",
    "Rename" : "Pārdēvēt",
    "Delete" : "Izdzēst",
    "Rename Feed" : "Pārdēvēt barotni",
    "Open Feed URL" : "Atvērt barotnes URL",
    "Newest first" : "Jaunākie pirms",
    "Oldest first" : "Vecākie pirms",
    "by" : "līdz",
    "Play audio" : "Atskaņot audio",
    "Download audio" : "Lejupielādēt audio",
    "Download video" : "Lejupielādēt video",
    "Open website" : "Atvērt tīmekļvietni",
    "Not available" : "Nav pieejams",
    "Title" : "Virsraksts",
    "Keyboard shortcut" : "Tastatūras saīsne",
    "Action" : "Darbība",
    "right" : "pa labi",
    "left" : "pa kreisi",
    "Open article in new tab" : "Atvērt rakstu jaunā cilnē",
    "Refresh" : "Atsvaidzināt",
    "Load previous folder" : "Ielādēt iepriekšējo mapi",
    "Load next folder" : "Ielādēt nākamo mapi"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n != 0 ? 1 : 2);");

==> nextcloud-app-news-1:28.0.0rc.2-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/news/l10n/lv.js <==
OC.L10N.register(
    "news",
    {
    "%1$s shared \"%2$s\" with you" : "%1$s koplietots \"%2$s\" ar tevi",
    "Unread articles" : "Nelasītie raksti",
    "Shared with me" : "Koplietots ar mani",
    "Download" : "Lejupielādēt",
    "Close" : "Aizvērt",
    "Web address" : "Tīmekļa adrese",
    "No folder" : "Nav mapes",
    "Folder name" : "Mapes nosaukums",
    "Username" : "Lietotājvārds",
    "Password" : "Parole",
    "Feed exists already!" : "Plūsma jau pastāv.",
    "New folder" : "Jauna mape",
    "Folder exists already!" : "Mape jau pastāv.",
    "Credentials" : "Akreditācijas dati",
    "Subscribe" : "Abonēt",
    "Maximum redirects" : "Lielākais pieļaujamais pārvirzījumu skaits",
    "Use system cron for updates" : "Izmantot sistēmas cron atjauninājumiem",
    "Show all articles" : "Rādīt visus rakstus",
    "Move" : "Pārvietot",
    "Share" : "Koplietot",
    "Rename Folder" : "Pārdēvēt mapi",
    "All articles" : "Visi raksti",
    "Starred" : "Svarīgs",
    "Explore" : "Izpētīt",
    "Rename" : "Pārdēvēt",
    "Delete" : "Izdzēst",
    "Rename Feed" : "Pārdēvēt barotni",
    "Open Feed URL" : "Atvērt barotnes URL",
    "Newest first" : "Jaunākie pirms",
    "Oldest first" : "Vecākie pirms",
    "by" : "līdz",
    "Play audio" : "Atskaņot audio",
    "Download audio" : "Lejupielādēt audio",
    "Download video" : "Lejupielādēt video",
    "Open website" : "Atvērt tīmekļvietni",
    "General" : "Vispārīgi",
    "Appearance" : "Izskats",
    "Import" : "Ievietot",
    "Export" : "Izgūt",
    "Keyboard shortcuts" : "Tastatūras saīsnes",
    "Refresh" : "Atsvaidzināt",
    "Open article in new tab" : "Atvērt rakstu jaunā cilnē",
    "Resources" : "Resursi",
    "Title" : "Virsraksts",
    "Folder" : "Mape",
    "Not available" : "Nav pieejams",
    "Ajax or webcron mode detected! Your feeds will not be updated!" : "Noteikts AJAX vai tīmekļa cron. Tavas barotnes netiks atjauninātas."
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n != 0 ? 1 : 2);");
